@@ -84,6 +84,17 @@ class Index:
         """Support Sentry."""
         return str(self)
 
+    @property
+    def name(self) -> Hashable:
+        """
+        Return the column key that forms the index.
+
+        If the index is multi-level, raise ValueError.
+        """
+        if len(index := self._parent._index) != 1:
+            raise ValueError(f"Index must be 1-D to use .name, have {len(index)}-D")
+        return index[0]
+
     @property
     def names(self) -> tuple[Hashable, ...]:
         """Return the column keys that form the index."""
@@ -127,17 +138,7 @@ class Index:
         columns = self._parent._columns
         if not columns:
             return np.array([], dtype=int)
-        order, merged = DataFrame._order([columns[c] for c in self._parent._index])
-        if keep == "last":
-            order = order[::-1]
-        _, first_found = np.unique(merged[order], return_index=True)
-        if len(first_found) < len(merged):
-            if keep == "last":
-                first_found = np.arange(len(merged), dtype=int)[order][first_found]
-            mask = np.ones(len(merged), dtype=bool)
-            mask[first_found] = False
-            return np.flatnonzero(mask)
-        return np.array([], dtype=int)
+        return self._parent.duplicated(self._parent._index, keep)
 
 
 @dataclass(frozen=True, slots=True)
@@ -341,7 +342,7 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
         :param value: Numpy array with column values. We set without copying, so the user should \
                       provide an array copy as needed.
         """
-        value = np.squeeze(np.asarray(value))
+        value = np.atleast_1d(np.squeeze(np.asarray(value)))
         if value.ndim != 1:
             raise ValueError(f"numpy array must be one-dimensional, got shape {value.shape}")
         if len(self) != len(value) and self._columns:
@@ -469,7 +470,7 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
             return self.reset_index() if ignore_index else self.copy()
         checked_types = (tuple, list, np.ndarray)
         repeat_counts = np.ones(len(values), dtype=int)
-        new_col = []
+        new_col: list[Any] = []
         for i, v in enumerate(values):
             if isinstance(v, checked_types):
                 repeat_counts[i] = len(v)
@@ -700,7 +701,7 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
 
     def drop_duplicates(
         self,
-        subset: Iterable[Hashable],
+        subset: Hashable | Iterable[Hashable] | None = None,
         keep: Literal["first", "last"] = "first",
         inplace: bool = False,
         ignore_index: bool = False,
@@ -710,25 +711,37 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
 
         We consider duplicates those rows which have the same values of columns in `subset`.
 
-        :param subset: Column key or several column keys.
+        :param subset: Column key or several column keys. None means all the columns.
         :param keep: "first" leaves the first encounters, while "last" leaves the last encounters.
         :param inplace: Update the current DataFrame instead of returning a deduplicated copy.
         :param ignore_index: Value indicating whether the resulting index will be reset.
+        :return: DataFrame with unique rows.
         """
         df = self if inplace else self.copy()
+        first_found = df._unique(subset, keep)
         if ignore_index:
             df._index = ()
-        by = [df[c] for c in subset]
-        order, merged = df._order(by, "stable")
-        if keep == "last":
-            order = order[::-1]
-        _, first_found = np.unique(merged[order], return_index=True)
-        if len(first_found) < len(merged):
-            if keep == "last":
-                first_found = np.arange(len(merged), dtype=int)[order][first_found]
+        if len(first_found) < len(df):
             return df.take(first_found, inplace=inplace)
         return df
 
+    def duplicated(
+        self,
+        subset: Hashable | Iterable[Hashable] | None = None,
+        keep: Literal["first", "last"] = "first",
+    ) -> npt.NDArray[np.int_]:
+        """
+        Return the indexes of duplicate rows.
+
+        :param subset: Column key or several column keys. None means all the columns.
+        :param keep: "first" leaves the first encounters, while "last" leaves the last encounters.
+        :return: Positions of the duplicates.
+        """
+        first_found = self._unique(subset, keep)
+        mask = np.ones(len(self), dtype=bool)
+        mask[first_found] = False
+        return np.flatnonzero(mask)
+
     def groupby(self, *by: Hashable | npt.ArrayLike) -> Grouper:
         """
         Group rows by one or more columns in `by`.
@@ -982,8 +995,9 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
             return cls()
         if len(dfs) > 255:
             raise ValueError(f"Cannot join more than 255 DataFrame-s, got {len(dfs)}")
-        if not isinstance(dfs[0], cls):
-            raise TypeError(f"Can only concatenate medvedi.DataFrame-s, got {type(dfs[0])}")
+        for df in dfs:
+            if not isinstance(df, cls):
+                raise TypeError(f"Can only concatenate medvedi.DataFrame-s, got {type(df)}")
         if not isinstance(suffixes, tuple):
             raise TypeError(f"`suffixes` must be a tuple, got {type(suffixes)}")
         if suffixes:
@@ -999,10 +1013,11 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
                 return dfs[0]
             return dfs[0].copy()
         indexes = [dfs[0]._index]
+        dtypes = [dfs[0]._columns[c].dtype for c in indexes[0]]
         for df in dfs[1:]:
-            if not isinstance(df, DataFrame):
-                raise TypeError(f"Joined objects must be DataFrame-s, got {type(df)}")
-            if df._index != indexes[0]:
+            if [df._columns[c].dtype for c in df._index] != dtypes and not (
+                (df.empty or dfs[0].empty) and len(df._index) == len(dtypes)
+            ):
                 raise ValueError(f"Incompatible indexes: {df._index} vs. {indexes[0]}")
             indexes.append(df._index)
         if indexes[0] == ():
@@ -1098,6 +1113,27 @@ class DataFrame(metaclass=PureStaticDataFrameMethods):
         merged = merge_to_str(*mapped_bys)
         return np.argsort(merged, kind=kind), merged
 
+    def _unique(
+        self,
+        subset: Hashable | Iterable[Hashable] | None,
+        keep: Literal["first", "last"],
+    ):
+        if subset is None:
+            subset = self._columns.keys()
+        elif subset in self._columns:
+            subset = (subset,)
+        if not isinstance(subset, Iterable):
+            raise TypeError(f"subset of columns is not recognized: {type(subset)}")
+        by = [self[c] for c in subset]
+        order, merged = self._order(by, "stable")
+        if keep == "last":
+            order = order[::-1]
+        _, first_found = np.unique(merged[order], return_index=True)
+        if len(first_found) < len(merged):
+            if keep == "last":
+                first_found = np.arange(len(merged), dtype=int)[order][first_found]
+        return first_found
+
     @staticmethod
     def _empty_array(length: int, dtype: np.dtype) -> np.ndarray:
         if dtype == object:
